SymbolFacade class

Constructors

SymbolFacade(Network network)

Properties

hashCode int
The hash code for this object.
no setterinherited
network Network
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

attachSignature(ITransaction transaction, Signature signature, {bool isPlainPayload = false}) String
bip32Path(int accountId) List<int>
cosignTransaction(KeyPair keyPair, ITransaction transaction, {bool detached = false}) → dynamic
hashTransaction(ITransaction transaction) Hash256
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signTransaction(KeyPair keyPair, ITransaction transaction) Signature
toString() String
A string representation of this object.
inherited
verifyTransaction(ITransaction transaction, Signature signature) bool

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bip32NodeToKeyPair(Bip32Node bip32Node) KeyPair
hashEmbeddedTransactions(List<IInnerTransaction> embeddedTransactions) Hash256