MosaicDefinition class

Implemented types

Constructors

MosaicDefinition({PublicKey? ownerPublicKey, MosaicId? id, Uint8List? description, List<SizePrefixedMosaicProperty>? properties, MosaicLevy? levy})

Properties

description Uint8List
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id MosaicId
getter/setter pair
levy MosaicLevy?
getter/setter pair
levySizeComputed int
no setter
ownerPublicKey PublicKey
getter/setter pair
ownerPublicKeySize int
final
properties List<SizePrefixedMosaicProperty>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
no setteroverride

Methods

deserialize(Uint8List payload) MosaicDefinition
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
override
sort() → void
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

TYPE_HINTS → const Map<String, String>