NonVerifiableNamespaceRegistrationTransactionV1 class

Implemented types

Constructors

NonVerifiableNamespaceRegistrationTransactionV1({TransactionType? type, int? version, NetworkType? network, Timestamp? timestamp, PublicKey? signerPublicKey, Amount? fee, Timestamp? deadline, Address? rentalFeeSink, Amount? rentalFee, Uint8List? name, Uint8List? parentName})

Properties

deadline Timestamp
getter/setter pair
entityBodyReserved_1 int
final
fee Amount
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name Uint8List
getter/setter pair
network NetworkType
getter/setter pair
parentName Uint8List?
getter/setter pair
rentalFee Amount
getter/setter pair
rentalFeeSink Address
getter/setter pair
rentalFeeSinkSize int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signerPublicKey PublicKey
getter/setter pair
signerPublicKeySize int
final
size int
no setteroverride
timestamp Timestamp
getter/setter pair
type TransactionType
getter/setter pair
version int
getter/setter pair

Methods

deserialize(Uint8List payload) NonVerifiableNamespaceRegistrationTransactionV1
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
override
sort() → void
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

TRANSACTION_TYPE TransactionType
final

Constants

TRANSACTION_VERSION → const int
TYPE_HINTS → const Map<String, String>