EmbeddedMosaicDefinitionTransactionV1 class

Implemented types

Constructors

EmbeddedMosaicDefinitionTransactionV1({PublicKey? signerPublicKey, int? version, NetworkType? network, TransactionType? type, MosaicId? id, BlockDuration? duration, MosaicNonce? nonce, MosaicFlags? flags, int? divisibility})

Properties

divisibility int
getter/setter pair
duration BlockDuration
getter/setter pair
embeddedTransactionHeaderReserved_1 int
final
entityBodyReserved_1 int
final
flags MosaicFlags
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id MosaicId
getter/setter pair
network NetworkType
getter/setter pair
nonce MosaicNonce
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signerPublicKey PublicKey
getter/setter pair
size int
no setteroverride
type TransactionType
getter/setter pair
version int
getter/setter pair

Methods

deserialize(Uint8List payload) EmbeddedMosaicDefinitionTransactionV1
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
override
sort() → void
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

TRANSACTION_TYPE TransactionType
final

Constants

TRANSACTION_VERSION → const int
TYPE_HINTS → const Map<String, String>