MosaicDefinitionTransactionV1 class

Implemented types

Constructors

MosaicDefinitionTransactionV1({Signature? signature, PublicKey? signerPublicKey, int? version, NetworkType? network, TransactionType? type, Amount? fee, Timestamp? deadline, MosaicId? id, BlockDuration? duration, MosaicNonce? nonce, MosaicFlags? flags, int? divisibility})

Properties

deadline Timestamp
getter/setter pair
divisibility int
getter/setter pair
duration BlockDuration
getter/setter pair
entityBodyReserved_1 int
final
fee Amount
getter/setter pair
flags MosaicFlags
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id MosaicId
getter/setter pair
network NetworkType
getter/setter pair
nonce MosaicNonce
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature Signature
getter/setter pairoverride
signerPublicKey PublicKey
getter/setter pairoverride
size int
no setteroverride
type TransactionType
getter/setter pairoverride
verifiableEntityHeaderReserved_1 int
final
version int
getter/setter pairoverride

Methods

deserialize(Uint8List payload) MosaicDefinitionTransactionV1
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
override
sort() → void
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

TRANSACTION_TYPE TransactionType
final

Constants

TRANSACTION_VERSION → const int
TYPE_HINTS → const Map<String, String>