MosaicGlobalRestrictionTransactionV1 class

Implemented types

Constructors

MosaicGlobalRestrictionTransactionV1({Signature? signature, PublicKey? signerPublicKey, int? version, NetworkType? network, TransactionType? type, Amount? fee, Timestamp? deadline, UnresolvedMosaicId? mosaicId, UnresolvedMosaicId? referenceMosaicId, BigInt? restrictionKey, BigInt? previousRestrictionValue, BigInt? newRestrictionValue, MosaicRestrictionType? previousRestrictionType, MosaicRestrictionType? newRestrictionType})

Properties

deadline Timestamp
getter/setter pair
entityBodyReserved_1 int
final
fee Amount
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mosaicId UnresolvedMosaicId
getter/setter pair
network NetworkType
getter/setter pair
newRestrictionType MosaicRestrictionType
getter/setter pair
newRestrictionValue BigInt
getter/setter pair
previousRestrictionType MosaicRestrictionType
getter/setter pair
previousRestrictionValue BigInt
getter/setter pair
referenceMosaicId UnresolvedMosaicId
getter/setter pair
restrictionKey BigInt
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature Signature
getter/setter pairoverride
signerPublicKey PublicKey
getter/setter pairoverride
size int
no setteroverride
type TransactionType
getter/setter pairoverride
verifiableEntityHeaderReserved_1 int
final
version int
getter/setter pairoverride

Methods

deserialize(Uint8List payload) MosaicGlobalRestrictionTransactionV1
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() Uint8List
override
sort() → void
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

TRANSACTION_TYPE TransactionType
final

Constants

TRANSACTION_VERSION → const int
TYPE_HINTS → const Map<String, String>