NamespaceExpiredReceipt class
- Implemented types
Constructors
- NamespaceExpiredReceipt({int? version, ReceiptType? type, NamespaceId? artifactId})
Properties
- artifactId ↔ NamespaceId
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
no setteroverride
- type ↔ ReceiptType
-
getter/setter pair
- version ↔ int
-
getter/setter pair
Methods
-
deserialize(
Uint8List payload) → NamespaceExpiredReceipt -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serialize(
) → Uint8List -
override
-
sort(
) → void -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- RECEIPT_TYPE → ReceiptType
-
final
Constants
-
TYPE_HINTS
→ const Map<
String, String>